@@ -13,9 +13,11 @@ class Settings:
 
     # pylint: disable=R0903
     def __init__(self, configuration: Optional[Dict[str, Any]] = None):
-        self.__real_time_update: bool = bool(configuration and configuration.get("realTimeUpdate"))
-        self.__is_consent_required = (configuration is not None) and \
-            (configuration.get("consentType") == self._CONSENT_TYPE_REQUIRED)
+        if configuration is None:
+            configuration = {}
+        self.__real_time_update: bool = bool(configuration.get("realTimeUpdate"))
+        self.__is_consent_required = configuration.get("consentType") == self._CONSENT_TYPE_REQUIRED
+        self.__data_api_domain = configuration.get("dataApiDomain")
 
     @property
     def real_time_update(self) -> bool:
@@ -26,3 +28,15 @@ class Settings:
     def is_consent_required(self) -> bool:
         """Returns consent required flag state"""
         return self.__is_consent_required
+
+    @property
+    def data_api_domain(self) -> Any:
+        """Returns Data API domain to be switched to"""
+        return self.__data_api_domain
+
+    def __str__(self):
+        return (
+            f"Settings{{real_time_update:{self.__real_time_update},"
+            f"is_consent_required:{self.__is_consent_required},"
+            f"data_api_domain:'{self.__data_api_domain}'}}"
+        )
