@@ -1,10 +1,11 @@
 """Visitor"""
 from threading import Lock
-from typing import Any, Callable, Optional, Dict, List, Iterator, cast
+from typing import Any, Callable, Optional, Dict, List, Iterator, Iterable, cast
 
 from kameleoon.data.visitor_visits import VisitorVisits
 from kameleoon.data.data import Data
 from kameleoon.data.browser import Browser
+from kameleoon.data.cbscores import CBScores
 from kameleoon.data.conversion import Conversion
 from kameleoon.data.cookie import Cookie
 from kameleoon.data.custom_data import CustomData
@@ -17,6 +18,8 @@ from kameleoon.data.page_view import PageView
 from kameleoon.data.unique_identifier import UniqueIdentifier
 from kameleoon.data.user_agent import UserAgent
 from kameleoon.data.manager.assigned_variation import AssignedVariation
+from kameleoon.data.manager.forced_experiment_variation import ForcedExperimentVariation
+from kameleoon.data.manager.forced_feature_variation import ForcedFeatureVariation
 from kameleoon.data.manager.page_view_visit import PageViewVisit
 from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.network.sendable import Sendable
@@ -26,7 +29,7 @@ EMPTY_DICT: Dict[Any, Any] = {}
 EMPTY_LIST: List[Any] = []
 
 
-class Visitor:
+class Visitor:  # pylint: disable=R0904
     """Visitor"""
     def __init__(self, source: Optional["Visitor"] = None) -> None:
         if source is None:
@@ -124,6 +127,45 @@ class Visitor:
         KameleoonLogger.debug('CALL/RETURN: Visitor.variations -> (variations: %s)', variations)
         return variations
 
+    def get_forced_feature_variation(self, feature_key: str) -> Optional[ForcedFeatureVariation]:
+        """
+        Returns an associated forced feature variation by its feature key if it is present.
+        Otherwise returns `None`.
+        """
+        KameleoonLogger.debug('CALL: Visitor.get_forced_feature_variation(feature_key: %s)', feature_key)
+        ffv = self._data.simulated_variations.get(feature_key) if self._data.simulated_variations else None
+        KameleoonLogger.debug(
+            'RETURN: Visitor.get_forced_feature_variation(feature_key: %s) -> (variation: %s)', feature_key, ffv
+        )
+        return ffv
+
+    def get_forced_experiment_variation(self, experiment_id: int) -> Optional[ForcedExperimentVariation]:
+        """
+        Returns an associated forced experiment variation by its experiment id if it is present.
+        Otherwise returns `None`.
+        """
+        KameleoonLogger.debug('CALL: Visitor.get_forced_experiment_variation(experiment_id: %s)', experiment_id)
+        fev = self._data.forced_variations.get(experiment_id) if self._data.forced_variations else None
+        KameleoonLogger.debug(
+            'RETURN: Visitor.get_forced_experiment_variation(experiment_id: %s) -> (variation: %s)', experiment_id, fev
+        )
+        return fev
+
+    def reset_forced_experiment_variation(self, experiment_id: int) -> None:
+        """Resets an associated forced experiment variation for some experiment id"""
+        KameleoonLogger.debug('CALL: Visitor.reset_forced_experiment_variation(experiment_id: %s)', experiment_id)
+        if self._data.forced_variations:
+            self._data.forced_variations.pop(experiment_id, None)
+        KameleoonLogger.debug('RETURN: Visitor.reset_forced_experiment_variation(experiment_id: %s)', experiment_id)
+
+    def update_simulated_variations(self, variations: Iterable[ForcedFeatureVariation]) -> None:
+        """Updates the associated simulated variations"""
+        if not (self._data.simulated_variations or variations):
+            return
+        KameleoonLogger.debug('CALL: Visitor.update_simulated_variations(variations: %s)', variations)
+        self._data.simulated_variations = {sv.feature_key: sv for sv in variations}
+        KameleoonLogger.debug('RETURN: Visitor.update_simulated_variations(variations: %s)', variations)
+
     @property
     def kcs_heat(self) -> Optional[KcsHeat]:
         """Returns the KCS heat data associated with this Visitor."""
@@ -131,6 +173,13 @@ class Visitor:
         KameleoonLogger.debug('CALL/RETURN: Visitor.kcs_heat -> (kcs_heat: %s)', kcs_heat)
         return kcs_heat
 
+    @property
+    def cbscores(self) -> Optional[CBScores]:
+        """Returns the CBS data associated with this Visitor."""
+        cbs = self._data.cbscores
+        KameleoonLogger.debug('CALL/RETURN: Visitor.cbscores -> (cbs: %s)', cbs)
+        return cbs
+
     @property
     def visitor_visits(self) -> Optional[VisitorVisits]:
         """Returns the visitor visits data associated with this Visitor."""
@@ -217,7 +266,10 @@ class Visitor:
             self.page_view_visits: Optional[Dict[str, PageViewVisit]] = None
             self.conversions: Optional[List[Conversion]] = None
             self.variations: Optional[Dict[int, AssignedVariation]] = None
+            self.forced_variations: Optional[Dict[int, ForcedExperimentVariation]] = None
+            self.simulated_variations: Optional[Dict[str, ForcedFeatureVariation]] = None
             self.kcs_heat: Optional[KcsHeat] = None
+            self.cbscores: Optional[CBScores] = None
             self.visitor_visits: Optional[VisitorVisits] = None
             self.mapping_identifier: Optional[str] = None
             self.legal_consent = False
@@ -294,6 +346,18 @@ class Visitor:
         if context.overwrite or variation.experiment_id not in self.variations:
             self._data.variations[variation.experiment_id] = variation
 
+    def _add_forced_feature_variation(self, context: DataAddingContext) -> None:
+        ffv = cast(ForcedFeatureVariation, context.data)
+        if self._data.simulated_variations is None:
+            self._data.simulated_variations = {}
+        self._data.simulated_variations[ffv.feature_key] = ffv
+
+    def _add_forced_experiment_variation(self, context: DataAddingContext) -> None:
+        fev = cast(ForcedExperimentVariation, context.data)
+        if self._data.forced_variations is None:
+            self._data.forced_variations = {}
+        self._data.forced_variations[fev.rule.experiment.id_] = fev
+
     def _set_browser(self, context: DataAddingContext) -> None:
         if context.overwrite or self._data.browser is None:
             self._data.browser = cast(Browser, context.data)
@@ -348,6 +412,10 @@ class Visitor:
     def _set_kcs_heat(self, context: DataAddingContext) -> None:
         self._data.kcs_heat = cast(KcsHeat, context.data)
 
+    def _set_cbscores(self, context: DataAddingContext) -> None:
+        if context.overwrite or self._data.cbscores is None:
+            self._data.cbscores = cast(CBScores, context.data)
+
     def _set_visitor_visits(self, context: DataAddingContext) -> None:
         self._data.visitor_visits = cast(VisitorVisits, context.data)
 
@@ -370,7 +438,10 @@ class Visitor:
         PageViewVisit: _add_page_view_visit,
         Conversion: _add_conversion,
         KcsHeat: _set_kcs_heat,
+        CBScores: _set_cbscores,
         VisitorVisits: _set_visitor_visits,
         AssignedVariation: _add_variation,
+        ForcedFeatureVariation: _add_forced_feature_variation,
+        ForcedExperimentVariation: _add_forced_experiment_variation,
         UniqueIdentifier: _set_is_unique_identifier,
     }
