@@ -29,3 +29,6 @@ class UserAgent(Data):
     @property
     def data_type(self) -> DataType:
         return DataType.USER_AGENT
+
+    def __str__(self):
+        return f"UserAgent{{value:'{self.__value}'}}"
