@@ -27,3 +27,6 @@ class VisitorVisits(BaseData):
     def get_previous_visit_timestamps(visitor_visits: Optional["VisitorVisits"]) -> List[int]:
         """Return timestamps for visit"""
         return visitor_visits.previous_visit_timestamps if visitor_visits is not None else []
+
+    def __str__(self):
+        return f"VisitorVisits{{previous_visit_timestamps:{self.__previous_visit_timestamps}}}"
