@@ -9,6 +9,7 @@ REGEX_DOMAIN = (
     r"^(\.?(([a-zA-Z\d][a-zA-Z\d-]*[a-zA-Z\d])|[a-zA-Z\d]))"
     r"(\.(([a-zA-Z\d][a-zA-Z\d-]*[a-zA-Z\d])|[a-zA-Z\d])){1,126}$"
 )
+LOCALHOST = "localhost"
 
 
 def validate_top_level_domain(top_level_domain: str) -> str:
@@ -35,8 +36,10 @@ def validate_top_level_domain(top_level_domain: str) -> str:
                 protocol, top_level_domain)
             break
 
-    if not re.match(REGEX_DOMAIN, top_level_domain):
-        KameleoonLogger.error(f"The top-level domain '{top_level_domain}' is invalid.")
-        return ""
+    if not re.match(REGEX_DOMAIN, top_level_domain) and top_level_domain != LOCALHOST:
+        KameleoonLogger.error(
+            f"The top-level domain '{top_level_domain}' is invalid. The value has been set as provided, but it does "
+            f"not meet the required format for proper SDK functionality. Please check the domain for correctness.")
+        return top_level_domain
 
     return top_level_domain
