@@ -1,13 +1,12 @@
 """ Kameleoon Real Time Configuration Service """
 import json
 from typing import Any, Callable, Dict, Optional
-import sseclient
+
 import requests
-from kameleoon.helpers.logger import Logger
-
+import sseclient
 
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.helpers.multi_threading import run_in_thread
-
 from kameleoon.real_time.real_time_event import RealTimeEvent
 
 KAMELEOON_REAL_TIME_CONFIGURATION_THREAD = "KameleoonRealTimeConfigurationThread"
@@ -20,7 +19,7 @@ class RealTimeConfigurationService:
     (experiments and feature flags) in real time
     """
 
-    def __init__(self, url: str, update_handler: Callable[[RealTimeEvent], Any], logger=None):
+    def __init__(self, url: str, update_handler: Callable[[RealTimeEvent], Any]):
         """
         For RealTimeConfigurationService must be provided an url
         from where it can read the updates
@@ -33,7 +32,6 @@ class RealTimeConfigurationService:
             "Cache-Control": "no-cache",
             "Connection": "Keep-Alive",
         }
-        self.logger = logger or Logger.shared()
         self.response: Optional[Any] = None
         self._create_sse_client()
 
@@ -42,7 +40,7 @@ class RealTimeConfigurationService:
             run_in_thread(self._run_sse_client, KAMELEOON_REAL_TIME_CONFIGURATION_THREAD, with_event_loop=True)
 
     def _run_sse_client(self):
-        self.logger.debug("Create SSE client")
+        KameleoonLogger.debug("Create SSE client")
         self.response = RealTimeConfigurationService._with_requests(self.url, self.headers)
         client = sseclient.SSEClient(self.response)
         try:
@@ -53,11 +51,12 @@ class RealTimeConfigurationService:
                     event_dict = json.loads(message.data)
                     self.update_handler(RealTimeEvent(event_dict))
         except Exception as ex:  # pylint: disable=W0703
-            self.logger.error(ex)
+            KameleoonLogger.error("Error occurred within SSE client: %s", ex)
             self._create_sse_client()
 
     def close(self) -> None:
         """Closes the connection to the server"""
+        KameleoonLogger.info('Real-time configuration service is shutting down')
         self.need_close = True
         if self.response is not None:
             self.response.close()
