@@ -2,6 +2,7 @@
 from typing import Any, Dict, Union
 from kameleoon.data import Device
 from kameleoon.data.device import DeviceType
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.targeting.conditions.targeting_condition import TargetingCondition
 
 
@@ -13,7 +14,7 @@ class DeviceCondition(TargetingCondition):
         try:
             self.__device_type = DeviceType[str(json_condition.get("device", "")).upper()]
         except KeyError as ex:
-            self._logger.error("%s has wrong JSON structure: %s", self.__class__, ex)
+            KameleoonLogger.error("%s has wrong JSON structure: %s", self.__class__, ex)
 
     def check(self, data: Any) -> bool:
         return isinstance(data, Device) and self.__check(data)
