@@ -1,5 +1,7 @@
 """Sdk language condition"""
 from typing import Any, Dict, Union
+
+from kameleoon.logging.kameleoon_logger import KameleoonLogger
 from kameleoon.sdk_version import SdkVersion
 from kameleoon.targeting.conditions.constants import TargetingOperator
 from kameleoon.targeting.conditions.targeting_condition import TargetingCondition
@@ -32,7 +34,7 @@ class SdkLanguageCondition(TargetingCondition):
             self.__version = json_condition.get("version", None)
             self.__operator = TargetingOperator[str(json_condition.get("versionMatchType", None))]
         except KeyError as ex:
-            self._logger.error("%s has wrong JSON structure: %s", self.__class__, ex)
+            KameleoonLogger.error("%s has wrong JSON structure: %s", self.__class__, ex)
 
     def check(self, data: Any) -> bool:
         return isinstance(data, SdkLanguageCondition.SdkInfo) and self.check_targeting(data)
@@ -73,5 +75,5 @@ class SdkLanguageCondition(TargetingCondition):
                 or (major_sdk == major_condition and minor_sdk == minor_condition and patch_sdk < patch_condition)
             )
 
-        self._logger.error("Unexpected comparing operation for SdkLanguage condition: %s", self.__operator)
+        KameleoonLogger.error("Unexpected comparing operation for SdkLanguage condition: %s", self.__operator)
         return False
