@@ -49,11 +49,11 @@ class TargetFeatureFlagCondition(TargetingCondition):
         return any(self.__check_rule(data, rule) for rule in self.__get_rules(data))
 
     def __check_rule(self, data: TargetFeatureFlagInfo, rule: Any) -> bool:
-        if rule is None or rule.experiment_id is None:
+        if rule is None or rule.experiment.id_ is None:
             return False
         if self.__condition_rule_id is not None and self.__condition_rule_id != rule.id_:
             return False
-        variation = data.variations_storage().get(rule.experiment_id, None)
+        variation = data.variations_storage().get(rule.experiment.id_, None)
         if variation is None:
             return False
         if self.__condition_variation_key is None:
