@@ -1,10 +1,13 @@
-from typing import Optional
+"""Targeting Segment"""
 
+from typing import Optional
 from kameleoon.exceptions import NotFoundError
 from kameleoon.targeting.tree_builder import create_tree
 
 
 class Segment:
+    """Segment with targeting data"""
+
     def __init__(self, *args) -> None:
         if args:
             if len(args) == 1:
@@ -12,18 +15,15 @@ class Segment:
                     raise NotFoundError("arguments for segment")
                 if "id" not in args[0]:
                     raise NotFoundError("id")
-                self.id = int(args[0]["id"])
+                self.id_ = int(args[0]["id"])
                 if "conditionsData" not in args[0]:
                     raise NotFoundError("conditionsData")
 
                 self.tree = create_tree(args[0]["conditionsData"])
             elif len(args) == 2:
-                self.id = args[0]
+                self.id_ = args[0]
                 self.tree = args[1]
 
     def check_tree(self, get_targeting_data) -> Optional[bool]:
-        if not self.tree:
-            is_targeted: Optional[bool] = True
-        else:
-            is_targeted = self.tree.check(get_targeting_data)
-        return is_targeted is True
\ No newline at end of file
+        """Checks the targeting throught targeting tree"""
+        return self.tree.check(get_targeting_data) if self.tree else True
