@@ -18,6 +18,8 @@ class RemoteVisitorDataFilter:
         conversions=False,
         experiments=False,
         kcs=False,
+        visitor_code=True,
+        cbs=False,
     ) -> None:
         self._previous_visit_amount = previous_visit_amount
         self._current_visit = current_visit
@@ -30,6 +32,8 @@ class RemoteVisitorDataFilter:
         self._conversions = conversions
         self._experiments = experiments
         self._kcs = kcs
+        self._visitor_code = visitor_code
+        self._cbs = cbs
 
     @property
     def previous_visit_amount(self) -> int:
@@ -86,10 +90,22 @@ class RemoteVisitorDataFilter:
         """True if KCS heat data will be retrieved"""
         return self._kcs
 
-    def __str__(self):
-        return (f"RemoteVisitorDataFilter{{previous_visit_amount:{self._previous_visit_amount},"
-                f"current_visit:{self._current_visit},custom_data:{self._custom_data},"
-                f"page_views:{self._page_views}, geolocation:{self._geolocation},"
-                f"device:{self._device},browser:{self._browser},"
-                f"operating_system:{self._operating_system},conversions:{self._conversions},"
-                f"experiments:{self._experiments},kcs:{self._kcs}}}")
+    @property
+    def visitor_code(self) -> bool:
+        """True if the `visitorCode` from the most recent visit will be retrieved and used for the current visit"""
+        return self._visitor_code
+
+    @property
+    def cbs(self) -> bool:
+        """True if CBS data will be retrieved"""
+        return self._cbs
+
+    def __str__(self) -> str:
+        return (
+            f"RemoteVisitorDataFilter{{previous_visit_amount:{self._previous_visit_amount},"
+            f"current_visit:{self._current_visit},custom_data:{self._custom_data},"
+            f"page_views:{self._page_views}, geolocation:{self._geolocation},"
+            f"device:{self._device},browser:{self._browser},"
+            f"operating_system:{self._operating_system},conversions:{self._conversions},"
+            f"experiments:{self._experiments},kcs:{self._kcs},visitor_code:{self._visitor_code}}},cbs:{self._cbs}"
+        )
